# cioat

The goal of this project is to visualize COVID-19's impact on airport traffic during Australia', 'Chile', 'Canada', 'United States of America (the).

Using a Geotab dataset, this dataset shows traffic to and from the Airport as a Percentage of the Traffic volume during the baseline period. 

The dataset is downloadable from:

https://github.com/jiaoyang-x/covidT/blob/main/covid_impact_on_airport_traffic.csv

# How to install cioat
You may need matplotlib library.

$ pip install matplotlib

$ pip install cioat

# How to run cioat
cioat program allows user to specify up to visualize COVID-19's impact on airport traffic.

$ python cioat.py

<img src='https://github.com/jiaoyang-x/covidT/blob/main/result.png' height=480 width=640>



